# README #

### What is this repository for? ###

* A set of modules to assist running the CCRenew Dashboard process
* 0.1.4
* [Learn Markdown](https://bitbucket.org/tutorials/markdowndemo)

### How do I get set up? ###

* Pip install ccrenew package
* Configuration
* Dependencies
* Database configuration
* How to run tests
* Deployment instructions

### Contribution guidelines ###

* Writing tests
* Code review
* Other guidelines

### Who do I talk to? ###

* Cypress Creek Renewables Performance Engineering Team